/*
Autor: Zbigniew Szymanski
E-mail: z.szymanski@szymanski-net.eu
Wersja: 1.1 
Historia zmian:
		1.1 dodano przeksztalcenie odwrotne PUWG 1992 ->WGS84
		1.0 przeksztalcenie WGS84 -> PUWG 1992
Data modyfikacji: 2012-11-27
Uwagi: Oprogramowanie darmowe. Dozwolone jest wykorzystanie i modyfikacja 
       niniejszego oprogramowania do wlasnych celow pod warunkiem 
       pozostawienia wszystkich informacji z naglowka. W przypadku 
       wykorzystania niniejszego oprogramowania we wszelkich projektach
       naukowo-badawczych, rozwojowych, wdrozeniowych i dydaktycznych prosze
       o zacytowanie nastepujacego artykulu:
       
       Zbigniew Szymanski, Stanislaw Jankowski, Jan Szczyrek, 
       "Reconstruction of environment model by using radar vector field histograms.",
       Photonics Applications in Astronomy, Communications, Industry, and 
       High-Energy Physics Experiments 2012, Proc. of SPIE Vol. 8454, pp. 845422 - 1-8,
       doi:10.1117/12.2001354
       
Literatura:
       Uriasz, J., Wybrane odwzorowania kartograficzne, Akademia Morska w Szczecinie,
       http://uriasz.am.szczecin.pl/naw_bezp/odwzorowania.html
*/

/*
  Przykladowy program demonstrujacy uzycie funkcji do przeliczania wspolrzednych z 
  ukladu WGS84 do ukladu PUWG 1992
*/
#include <stdio.h>
#include "wgs84_do_puwg92.h"

int main(void)
    {
    double B_stopnie=52.00;
    double L_stopnie=19.00;
    double Xpuwg;
    double Ypuwg;
    double B1_stopnie;
    double L1_stopnie;
    
    if (wgs84_do_puwg92(B_stopnie, L_stopnie, &Xpuwg, &Ypuwg)!=0)
        {
        printf("\nBlad: parametry wejsciowe poza dopuszczalnym zakresem.\n");
	}
    else
	{
	printf("WGS 84 -> PUWG 1992\n");
	printf("B:%11.4f  L:%11.4f\n",B_stopnie, L_stopnie);
	printf("X:%11.4f  Y:%11.4f\n\n",Xpuwg, Ypuwg);
	//UWAGA - w ukladzie PUWG1992 wspolrzedna pozioma to Y, a pionowa to X
	
	puwg92_do_wgs84(Xpuwg, Ypuwg, &B1_stopnie, &L1_stopnie);
	printf("PUWG 1992 -> WGS 84\n");
	printf("X:%11.4f  Y:%11.4f\n",Xpuwg, Ypuwg);
	printf("B:%11.4f  L:%11.4f\n",B1_stopnie, L1_stopnie);
	}
    return 0;
    }
    